@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Log::Dispatchouli;
 # ABSTRACT: a simple wrapper around Log::Dispatch
-$Log::Dispatchouli::VERSION = '2.014';
+$Log::Dispatchouli::VERSION = '2.018';
 use Carp ();
 use File::Spec ();
 use Log::Dispatch;
@@ -123,6 +123,7 @@ our @CARP_NOT = qw(Log::Dispatchouli::Proxy);
 #pod                 fatal log messages will not be logged to these
 #pod                 (default: stderr)
 #pod   config_id   - a name for this logger's config; rarely needed!
+#pod   syslog_socket - a value for Sys::Syslog's "socket" arg; default: "native"
 #pod
 #pod The log path is either F</tmp> or the value of the F<DISPATCHOULI_PATH> env var.
 #pod
@@ -154,8 +155,8 @@ sub new {
     $pid_prefix
     ? (
         callbacks => sub {
-	  "[$$] ". {@_}->{message}
-	},
+          "[$$] ". {@_}->{message}
+        },
       )
     : ()
   );
@@ -202,7 +203,7 @@ sub new {
         facility  => $arg->{facility},
         ident     => $ident,
         logopt    => 'pid',
-        socket    => 'native',
+        socket    => $arg->{syslog_socket} || 'native',
         callbacks => sub {
           ( my $m = {@_}->{message} ) =~ s/\n/<LF>/g;
           $m
@@ -225,16 +226,9 @@ sub new {
 
   DEST: for my $dest (qw(err out)) {
     next DEST unless $arg->{"to_std$dest"};
-    require Log::Dispatch::Screen;
-    $log->add(
-      Log::Dispatch::Screen->new(
-        name      => "std$dest",
-        min_level => 'debug',
-        stderr    => ($dest eq 'err' ? 1 : 0),
-        callbacks => sub { +{@_}->{message} . "\n" },
-        ($quiet_fatal{"std$dest"} ? (max_level => 'info') : ()),
-      ),
-    );
+    my $method = "enable_std$dest";
+
+    $self->$method;
   }
 
   $self->{dispatcher} = $log;
@@ -245,12 +239,34 @@ sub new {
   $self->{debug}  = exists $arg->{debug}
                   ? ($arg->{debug} ? 1 : 0)
                   : ($self->env_value('DEBUG') ? 1 : 0);
+  $self->{muted}  = $arg->{muted};
 
-  $self->{fail_fatal} = exists $arg->{fail_fatal} ? $arg->{fail_fatal} : 1;
+  $self->{quiet_fatal} = \%quiet_fatal;
+  $self->{fail_fatal}  = exists $arg->{fail_fatal} ? $arg->{fail_fatal} : 1;
 
   return $self;
 }
 
+for my $dest (qw(out err)) {
+  my $name = "std$dest";
+  my $code = sub {
+    return if $_[0]->dispatcher->output($name);
+    require Log::Dispatch::Screen;
+    $_[0]->dispatcher->add(
+      Log::Dispatch::Screen->new(
+        name      => "std$dest",
+        min_level => 'debug',
+        stderr    => ($dest eq 'err' ? 1 : 0),
+        callbacks => sub { +{@_}->{message} . "\n" },
+        ($_[0]{quiet_fatal}{"std$dest"} ? (max_level => 'info') : ()),
+      ),
+    );
+  };
+
+  no strict 'refs';
+  *{"enable_std$dest"} = $code;
+}
+
 #pod =method log
 #pod
 #pod   $logger->log(@messages);
@@ -592,12 +608,15 @@ sub clear_events {
 #pod
 #pod =cut
 
+sub proxy_class {
+  return 'Log::Dispatchouli::Proxy';
+}
+
 sub proxy {
   my ($self, $arg) = @_;
   $arg ||= {};
 
-  require Log::Dispatchouli::Proxy;
-  Log::Dispatchouli::Proxy->_new({
+  $self->proxy_class->_new({
     parent => $self,
     logger => $self,
     proxy_prefix => $arg->{proxy_prefix},
@@ -693,7 +712,7 @@ Log::Dispatchouli - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 2.014
+version 2.018
 
 =head1 SYNOPSIS
 
@@ -762,6 +781,7 @@ Valid arguments are:
                 fatal log messages will not be logged to these
                 (default: stderr)
   config_id   - a name for this logger's config; rarely needed!
+  syslog_socket - a value for Sys::Syslog's "socket" arg; default: "native"
 
 The log path is either F</tmp> or the value of the F<DISPATCHOULI_PATH> env var.
 
@@ -1041,7 +1061,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen Dagfinn Ilmari Mannsåker George Hartzell Matt Phillips Olivier Mengué Randy Stauner Sawyer X
+=for stopwords Christopher J. Madsen Dagfinn Ilmari Mannsåker Dan Book George Hartzell Jon Stuart Matt Phillips Olivier Mengué Randy Stauner Sawyer X
 
 =over 4
 
@@ -1055,10 +1075,18 @@ Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 =item *
 
+Dan Book <grinnz@gmail.com>
+
+=item *
+
 George Hartzell <hartzell@alerce.com>
 
 =item *
 
+Jon Stuart <jon@fastmailteam.com>
+
+=item *
+
 Matt Phillips <mattp@cpan.org>
 
 =item *
@@ -1077,7 +1105,7 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
