@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Log::Dispatchouli::Proxy;
 # ABSTRACT: a simple wrapper around Log::Dispatch
-$Log::Dispatchouli::Proxy::VERSION = '2.014';
+$Log::Dispatchouli::Proxy::VERSION = '2.018';
 use Params::Util qw(_ARRAY0 _HASH0);
 
 #pod =head1 DESCRIPTION
@@ -130,6 +130,11 @@ sub info  { shift()->log(@_); }
 sub fatal { shift()->log_fatal(@_); }
 sub debug { shift()->log_debug(@_); }
 
+use overload
+  '&{}'    => sub { my ($self) = @_; sub { $self->log(@_) } },
+  fallback => 1,
+;
+
 1;
 
 __END__
@@ -144,7 +149,7 @@ Log::Dispatchouli::Proxy - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 2.014
+version 2.018
 
 =head1 DESCRIPTION
 
@@ -177,7 +182,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2019 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
